@@ -33,10 +33,11 @@
 #  define KNOTIFYCONFIG_DEPRECATED_NO_EXPORT KNOTIFYCONFIG_NO_EXPORT KNOTIFYCONFIG_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KNOTIFYCONFIG_NO_DEPRECATED
 #    define KNOTIFYCONFIG_NO_DEPRECATED
 #  endif
 #endif
 
-#endif
+#endif /* KNOTIFYCONFIG_EXPORT_H */
